@@ -13,7 +13,12 @@ class MergeStrategy(Enum):
     THEIRS = 2
 
 
+# TODO: Derive from MutableMapping (-> rename get() to get_value())
 class ParamStore(ABC):
+    @abstractmethod
+    def keys(self):
+        pass
+
     @abstractmethod
     def to_dict(self):
         pass
@@ -38,7 +43,7 @@ class ParamStore(ABC):
         pass
 
     @abstractmethod
-    def checkout(self, commit_id: str, commit_num: int, move_by: int):
+    def checkout(self, commit_id: str, commit_num: int = None, move_by: int = None):
         pass
 
     @abstractmethod
